Logic Bank Utility Functions
============================

.. code-block:: Python

    def add_python_path(project_dir: str, my_file: str) -> (str, str):
        """
        @param project_dir: enclosing path node (e.g., LogicBank
        @param my_file: callers __file__ variable
        @result (path_was_fixed, path)
        """


Depends on:
-----------
- Python 3.8



Change Log
----------

0.0.1 - Initial Version
